@@ -1,14 +1,14 @@
 from contextlib import suppress
 from enum import Enum, unique
-from typing import DefaultDict, Optional
+from typing import DefaultDict, Union
 
-import attr
+import attrs
 
-from ..annotations import DictStrAny, DictStrStr
-from ..configs import UpdateConfig
-from ..enums import ProjectTypeEnum
-from .formatting import format_version
-from .parsing import parse_version
+from badabump.annotations import DictStrAny, DictStrStr
+from badabump.configs import UpdateConfig
+from badabump.enums import ProjectTypeEnum
+from badabump.versions.formatting import format_version
+from badabump.versions.parsing import parse_version
 
 
 SCHEMA_MAPPING: DefaultDict[ProjectTypeEnum, str] = DefaultDict(
@@ -48,7 +48,7 @@ PRE_RELEASE_TYPE_MAPPING = {
 }
 
 
-@attr.dataclass(frozen=True, slots=True)
+@attrs.frozen(slots=True, kw_only=True)
 class PreRelease:
     pre_release_type: PreReleaseTypeEnum = PreReleaseTypeEnum.alpha
     number: int = 0
@@ -94,7 +94,7 @@ class PreRelease:
             "project type"
         )
 
-    def update(self, config: UpdateConfig) -> Optional["PreRelease"]:
+    def update(self, config: UpdateConfig) -> Union["PreRelease", None]:
         if config.is_pre_release is False:
             return None
 
